@@ -7,10 +7,6 @@ context("macroACS methods")
 #----------------------------------------------------------
 
 test_that("fetch - age_by_sex - estimates work", {
-  # load test data:
-  load("C:/Github/synthACS/tests/testthat/acsdat.Rdata")
-  rm(list=ls()[-which(ls() == "ca_dat")])
-  
   # run function on all types of use cases
   options(warn=-1)
   age_sex_vector_all <- fetch_data(ca_dat, geography= "*", dataset= "estimate",
@@ -48,10 +44,6 @@ test_that("fetch - age_by_sex - estimates work", {
 })
 
 test_that("fetch - age_by_sex - SE work", {
-  # load test data:
-  load("C:/Github/synthACS/tests/testthat/acsdat.Rdata")
-  rm(list=ls()[-which(ls() == "ca_dat")])
-  
   # run function on all types of use cases
   options(warn=-1)
   age_sex_vector_all <- fetch_data(ca_dat, geography= "*", dataset= "st.err",
@@ -89,10 +81,6 @@ test_that("fetch - age_by_sex - SE work", {
 
 #----------------------------
 test_that("fetch - pop_by_race - estimates work", {
-  # load test data:
-  load("C:/Github/synthACS/tests/testthat/acsdat.Rdata")
-  rm(list=ls()[-which(ls() == "ca_dat")])
-  
   # run function on all types of use cases
   options(warn=-1)
   vector_all <- fetch_data(ca_dat, geography= "*", dataset= "estimate",
@@ -130,10 +118,6 @@ test_that("fetch - pop_by_race - estimates work", {
 })
 
 test_that("fetch - pop_by_race - SE work", {
-  # load test data:
-  load("C:/Github/synthACS/tests/testthat/acsdat.Rdata")
-  rm(list=ls()[-which(ls() == "ca_dat")])
-  
   # run function on all types of use cases
   options(warn=-1)
   vector_all <- fetch_data(ca_dat, geography= "*", dataset= "st.err",
@@ -173,10 +157,6 @@ test_that("fetch - pop_by_race - SE work", {
 
 #----------------------------
 test_that("span, endyear, geography, dataset names", {
-  # load test data:
-  load("C:/Github/synthACS/tests/testthat/acsdat.Rdata")
-  rm(list=ls()[-which(ls() == "ca_dat")])
-  
   sp <- get_span(ca_dat)
   expect_equal(sp, ca_dat$span)
   
@@ -195,9 +175,6 @@ test_that("span, endyear, geography, dataset names", {
 
 #----------------------------
 test_that("split macroACS works", {
-  load("C:/Github/synthACS/tests/testthat/acsdat.Rdata")
-  rm(list=ls()[-which(ls() == "ca_dat")])
-  
   # run function
   ca_split <- split(ca_dat, n_splits= 7)
   # comparison / manual
