@@ -1,9 +1,4 @@
 
-# library(synthACS)
-# ca_geo <- geo.make(state= 'CA', county= '*')
-# ca_dat <- pull_synth_data(2012, 5, ca_geo)
-# save.image("C:/Github/synthACS/tests/testthat/acsdat.Rdata")
-
 library(testthat)
 library(synthACS)
 
@@ -20,12 +15,6 @@ test_that("appropriate inputs", {
 
 
 test_that("creates expected result", {
-  ##---------------------------------------------------------------------------
-  ## 01. build out test datasets
-  ##---------------------------------------------------------------------------
-  # load
-  load("C:/Github/synthACS/tests/testthat/acsdat.Rdata")
-  
   # then create multiple examples
   ca <- synthACS:::synth_data_ag(unlist(ca_dat$estimates$age_by_sex[26,]))
   
